
# Catálogo: Cosechando Datos Argentina

## Información General

- **Autor**: Ministerio de Modernización
- **Correo Electrónico**: datos@modernizacion.gob.ar
- **Ruta del catálogo**: tests/samples/several_datasets_for_harvest.json
- **Nombre del catálogo**: Cosechando Datos Argentina
- **Descripción**:

> Datasets para reporte pre cosecha

## Estado de los metadatos y cantidad de recursos

- **Estado metadatos globales**: ERROR
- **Estado metadatos catálogo**: OK
- **Cantidad Total de Datasets**: 3
- **Cantidad Total de Distribuciones**: 6

- **Cantidad de Datasets Federados**: 0
- **Cantidad de Datasets NO Federados**: 3
- **Porcentaje de Datasets NO Federados**: 100.0%

## Datasets no federados:

- [Sistema de contrataciones electrónicas UNO](None)
- [Sistema de contrataciones electrónicas DOS](None)
- [Sistema de contrataciones electrónicas TRES](None)

## Datasets incluidos

Por favor, consulte el informe [`datasets.csv`](datasets.csv).
